@@ -51,7 +51,6 @@ int send_traffic_stat(uint64_t tx, uint64_t rx);
 #define STAGE_ERROR     -1  /* Error detected                   */
 #define STAGE_INIT       0  /* Initial stage                    */
 #define STAGE_HANDSHAKE  1  /* Handshake with client            */
-#define STAGE_PARSE      2  /* Parse the SOCKS5 header          */
 #define STAGE_SNI        3  /* Parse HTTP/SNI header            */
 #define STAGE_RESOLVE    4  /* Resolve the hostname             */
 #define STAGE_STREAM     5  /* Stream between client and server */
@@ -70,7 +69,8 @@ enum {
     GETOPT_VAL_PASSWORD,
     GETOPT_VAL_KEY,
     GETOPT_VAL_MANAGER_ADDRESS,
-    GETOPT_VAL_EXECUTABLE
+    GETOPT_VAL_EXECUTABLE,
+    GETOPT_VAL_WORKDIR,
 };
 
 #endif // _COMMON_H
