@@ -43,11 +43,6 @@
 #define TCP_AND_UDP  1
 #define UDP_ONLY     3
 
-typedef struct {
-    char *host;
-    char *port;
-} ss_addr_t;
-
 typedef struct {
     char *port;
     char *password;
