@@ -1,7 +1,7 @@
 /*
  * netutils.c - Network utilities
  *
- * Copyright (C) 2013 - 2017, Max Lv <max.c.lv@gmail.com>
+ * Copyright (C) 2013 - 2018, Max Lv <max.c.lv@gmail.com>
  *
  * This file is part of the shadowsocks-libev.
  *
@@ -23,15 +23,17 @@
 #include <math.h>
 
 #include <libcork/core.h>
-#include <udns.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifndef __MINGW32__
+#include <arpa/inet.h>
 #include <netdb.h>
 #include <netinet/in.h>
 #include <unistd.h>
+#endif
 
 #if defined(HAVE_SYS_IOCTL_H) && defined(HAVE_NET_IF_H) && defined(__linux__)
 #include <net/if.h>
@@ -51,10 +53,6 @@ extern int verbose;
 static const char valid_label_bytes[] =
     "-0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz";
 
-#if defined(MODULE_LOCAL)
-extern int keep_resolving;
-#endif
-
 int
 set_reuseport(int socket)
 {
@@ -79,7 +77,7 @@ setinterface(int socket_fd, const char *interface_name)
 {
     struct ifreq interface;
     memset(&interface, 0, sizeof(struct ifreq));
-    strncpy(interface.ifr_name, interface_name, IFNAMSIZ);
+    strncpy(interface.ifr_name, interface_name, IFNAMSIZ - 1);
     int res = setsockopt(socket_fd, SOL_SOCKET, SO_BINDTODEVICE, &interface,
                          sizeof(struct ifreq));
     return res;
@@ -90,19 +88,22 @@ setinterface(int socket_fd, const char *interface_name)
 int
 bind_to_address(int socket_fd, const char *host)
 {
-    if (host != NULL) {
+    static struct sockaddr_storage storage = { 0 };
+    if (storage.ss_family == AF_INET) {
+        return bind(socket_fd, (struct sockaddr *)&storage, sizeof(struct sockaddr_in));
+    } else if (storage.ss_family == AF_INET6) {
+        return bind(socket_fd, (struct sockaddr *)&storage, sizeof(struct sockaddr_in6));
+    } else if (host != NULL) {
         struct cork_ip ip;
-        struct sockaddr_storage storage;
-        memset(&storage, 0, sizeof(struct sockaddr_storage));
         if (cork_ip_init(&ip, host) != -1) {
             if (ip.version == 4) {
                 struct sockaddr_in *addr = (struct sockaddr_in *)&storage;
-                dns_pton(AF_INET, host, &addr->sin_addr);
+                inet_pton(AF_INET, host, &addr->sin_addr);
                 addr->sin_family = AF_INET;
                 return bind(socket_fd, (struct sockaddr *)addr, sizeof(struct sockaddr_in));
             } else if (ip.version == 6) {
                 struct sockaddr_in6 *addr = (struct sockaddr_in6 *)&storage;
-                dns_pton(AF_INET6, host, &addr->sin6_addr);
+                inet_pton(AF_INET6, host, &addr->sin6_addr);
                 addr->sin6_family = AF_INET6;
                 return bind(socket_fd, (struct sockaddr *)addr, sizeof(struct sockaddr_in6));
             }
@@ -121,20 +122,24 @@ get_sockaddr(char *host, char *port,
         if (ip.version == 4) {
             struct sockaddr_in *addr = (struct sockaddr_in *)storage;
             addr->sin_family = AF_INET;
-            dns_pton(AF_INET, host, &(addr->sin_addr));
+            inet_pton(AF_INET, host, &(addr->sin_addr));
             if (port != NULL) {
                 addr->sin_port = htons(atoi(port));
             }
         } else if (ip.version == 6) {
             struct sockaddr_in6 *addr = (struct sockaddr_in6 *)storage;
             addr->sin6_family = AF_INET6;
-            dns_pton(AF_INET6, host, &(addr->sin6_addr));
+            inet_pton(AF_INET6, host, &(addr->sin6_addr));
             if (port != NULL) {
                 addr->sin6_port = htons(atoi(port));
             }
         }
         return 0;
     } else {
+#ifdef __ANDROID__
+        extern int vpn;
+        assert(!vpn);   // protecting DNS packets isn't supported yet
+#endif
         struct addrinfo hints;
         struct addrinfo *result, *rp;
 
@@ -142,21 +147,7 @@ get_sockaddr(char *host, char *port,
         hints.ai_family   = AF_UNSPEC;   /* Return IPv4 and IPv6 choices */
         hints.ai_socktype = SOCK_STREAM; /* We want a TCP socket */
 
-        int err, i;
-
-        for (i = 1; i < 8; i++) {
-            err = getaddrinfo(host, port, &hints, &result);
-#if defined(MODULE_LOCAL)
-            if (!keep_resolving)
-                break;
-#endif
-            if ((!block || !err)) {
-                break;
-            } else {
-                sleep(pow(2, i));
-                LOGE("failed to resolve server name, wait %.0f seconds", pow(2, i));
-            }
-        }
+        int err = getaddrinfo(host, port, &hints, &result);
 
         if (err != 0) {
             LOGE("getaddrinfo: %s", gai_strerror(err));
@@ -207,9 +198,6 @@ sockaddr_cmp(struct sockaddr_storage *addr1,
         return -1;
     if (p1_in->sin_family > p2_in->sin_family)
         return 1;
-    if (verbose) {
-        LOGI("sockaddr_cmp: sin_family equal? %d", p1_in->sin_family == p2_in->sin_family);
-    }
     /* compare ip4 */
     if (p1_in->sin_family == AF_INET) {
         /* just order it, ntohs not required */
@@ -217,9 +205,6 @@ sockaddr_cmp(struct sockaddr_storage *addr1,
             return -1;
         if (p1_in->sin_port > p2_in->sin_port)
             return 1;
-        if (verbose) {
-            LOGI("sockaddr_cmp: sin_port equal? %d", p1_in->sin_port == p2_in->sin_port);
-        }
         return memcmp(&p1_in->sin_addr, &p2_in->sin_addr, INET_SIZE);
     } else if (p1_in6->sin6_family == AF_INET6) {
         /* just order it, ntohs not required */
@@ -227,9 +212,6 @@ sockaddr_cmp(struct sockaddr_storage *addr1,
             return -1;
         if (p1_in6->sin6_port > p2_in6->sin6_port)
             return 1;
-        if (verbose) {
-            LOGI("sockaddr_cmp: sin6_port equal? %d", p1_in6->sin6_port == p2_in6->sin6_port);
-        }
         return memcmp(&p1_in6->sin6_addr, &p2_in6->sin6_addr,
                       INET6_SIZE);
     } else {
@@ -301,3 +283,19 @@ validate_hostname(const char *hostname, const int hostname_len)
 
     return 1;
 }
+
+int
+is_ipv6only(ss_addr_t *servers, size_t server_num)
+{
+    struct cork_ip ip;
+    int i;
+    for (i = 0; i < server_num; i++)
+    {
+        if (cork_ip_init(&ip, servers[i].host) != -1) {
+            if (ip.version != 6) {
+                return 0;
+            }
+        }
+    }
+    return 1;
+}
