@@ -52,6 +52,11 @@
 #endif
 #endif
 
+typedef struct {
+    char *host;
+    char *port;
+} ss_addr_t;
+
 /* MPTCP_ENABLED setsockopt values for kernel 4 & 3, best behaviour to be independant of kernel version is to test from newest to the latest values */
 #ifndef MPTCP_ENABLED
 static const char mptcp_enabled_values[] = { 42, 26, 0 };
@@ -103,4 +108,6 @@ int sockaddr_cmp_addr(struct sockaddr_storage *addr1,
 
 int validate_hostname(const char *hostname, const int hostname_len);
 
+int is_ipv6only(ss_addr_t *servers, size_t server_num);
+
 #endif
