@@ -1,7 +1,7 @@
 /*
  * shadowsocks.h - Header files of library interfaces
  *
- * Copyright (C) 2013 - 2016, Max Lv <max.c.lv@gmail.com>
+ * Copyright (C) 2013 - 2018, Max Lv <max.c.lv@gmail.com>
  *
  * This file is part of the shadowsocks-libev.
  * shadowsocks-libev is free software; you can redistribute it and/or modify
@@ -37,7 +37,6 @@ typedef struct {
     char *log;            // file path to log
     int fast_open;        // enable tcp fast open
     int mode;             // enable udp relay
-    int auth;             // enable one-time authentication
     int mtu;              // MTU of interface
     int mptcp;            // enable multipath TCP
     int verbose;          // verbose mode
@@ -57,7 +56,6 @@ typedef struct {
  *  .log = NULL,
  *  .fast_open = 0,
  *  .mode = 0,
- *  .auth = 0,
  *  .verbose = 0
  * };
  */
@@ -66,6 +64,8 @@ typedef struct {
 extern "C" {
 #endif
 
+typedef void (*ss_local_callback)(int socks_fd, int udp_fd, void *data);
+
 /*
  * Create and start a shadowsocks local server.
  *
@@ -79,6 +79,16 @@ extern "C" {
  */
 int start_ss_local_server(profile_t profile);
 
+/*
+ * Create and start a shadowsocks local server, specifying a callback.
+ *
+ * The callback is invoked when the local server has started successfully. It passes the SOCKS
+ * server and UDP relay file descriptors, along with any supplied user data.
+ *
+ * Returns -1 on failure.
+ */
+int start_ss_local_server_with_callback(profile_t profile, ss_local_callback callback, void *udata);
+
 #ifdef __cplusplus
 }
 #endif
