@@ -1,7 +1,7 @@
 /*
  * udprelay.h - Define UDP relay's buffers and callbacks
  *
- * Copyright (C) 2013 - 2017, Max Lv <max.c.lv@gmail.com>
+ * Copyright (C) 2013 - 2018, Max Lv <max.c.lv@gmail.com>
  *
  * This file is part of the shadowsocks-libev.
  *
@@ -44,7 +44,8 @@
 
 #define MAX_UDP_PACKET_SIZE (65507)
 
-#define DEFAULT_PACKET_SIZE 1397 // 1492 - 1 - 28 - 2 - 64 = 1397, the default MTU for UDP relay
+#define PACKET_HEADER_SIZE (1 + 28 + 2 + 64)
+#define DEFAULT_PACKET_SIZE 1397 // 1492 - PACKET_HEADER_SIZE = 1397, the default MTU for UDP relay
 
 typedef struct server_ctx {
     ev_io io;
@@ -67,7 +68,6 @@ typedef struct server_ctx {
 
 #ifdef MODULE_REMOTE
 typedef struct query_ctx {
-    struct ResolvQuery *query;
     struct sockaddr_storage src_addr;
     buffer_t *buf;
     int addr_header_len;
